View source: R/create_pandas_statement.R
| create_pandas_statement | R Documentation |
This internal function assembles a Python command string for pandas by chaining together different data manipulation methods. It serves as the central command generator for the package.
create_pandas_statement(
df_name,
filter_str = NULL,
select_str = NULL,
sort_by_str = NULL,
sort_asc_str = NULL,
assign_str = NULL,
drop_str = NULL,
groupby_str = NULL,
agg_str = NULL,
head_k = NULL,
tail_k = NULL
)
df_name |
A character string for the name of the pandas DataFrame. |
filter_str |
A string for the |
select_str |
A string for column selection (e.g., |
sort_by_str |
A string for the |
sort_asc_str |
A string for the |
assign_str |
A string for the |
drop_str |
A string for the |
groupby_str |
A string for the |
agg_str |
A string for the |
head_k |
Integer for |
tail_k |
Integer for |
A character string of the complete, chained pandas command.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.