View source: R/execute_pandas_statement.R
| execute_pandas_statement | R Documentation |
This is the core execution engine. It explicitly injects an R data frame into the Python session, runs a command, retrieves the result, and cleans up.
execute_pandas_statement(
r_df,
py_command,
table_name = table_name,
return.as = "result"
)
r_df |
An R data.frame. |
py_command |
A character string of Python code using 'df' as a placeholder. |
table_name |
An optional character string. If provided, the generated Python code will replace the internal dataframe name with this string (e.g., |
return.as |
What to return: "result", "code", or "all". |
The result of the execution.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.