| rp_check_env | R Documentation |
This function checks if the user's system is correctly configured with Python and the pandas library. If dependencies are missing, it stops with a detailed diagnostic report and actionable instructions (only in interactive sessions). In non‑interactive contexts (e.g., CRAN checks), it issues a warning and returns FALSE.
rp_check_env()
Invisibly returns TRUE if all checks pass, otherwise FALSE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.