| rp_count | R Documentation |
This function returns the number of rows in a data frame. When grouping
variables are provided via .by, it returns the row counts for each group.
rp_count(.data, .by = NULL, table_name = NULL, return.as = "result")
.data |
An R data frame (or tibble) to be processed. |
.by |
Optional grouping variables. Can be one or more unquoted column names
(e.g., |
table_name |
An optional character string. If provided, the generated Python code will replace the internal dataframe name with this string (e.g., |
return.as |
One of |
A data frame with one column "n" (total row count) if .by = NULL,
or a data frame with the grouping columns and a column "n" (per‑group counts).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.