| rp_filter | R Documentation |
Filters a data frame using an R expression translated to pandas.
rp_filter(.data, filter_expression, table_name = NULL, return.as = "result")
.data |
An R data.frame or tibble. |
filter_expression |
The filtering expression, written in R syntax. |
table_name |
An optional character string. If provided, the generated Python code will replace the internal dataframe name with this string (e.g., |
return.as |
What to return: "result", "code", or "all". |
A data.frame containing the filtered rows.
if (reticulate::py_available(initialize = TRUE) &&
reticulate::py_module_available("pandas")) {
rp_filter(ggplot2::diamonds, carat > 1 & price < 4000)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.