| rp_first_k_rows | R Documentation |
This function returns the first k rows of the data frame. If grouping variables
are provided via .by, it returns the first k rows within each group.
rp_first_k_rows(.data, k, .by = NULL, table_name = NULL, return.as = "result")
.data |
An R data frame (or tibble) to be processed. |
k |
An integer specifying the number of rows to return. If |
.by |
Optional grouping variables. Can be one or more unquoted column names. When provided, the operation is performed on each group separately. |
table_name |
An optional character string. If provided, the generated Python code will replace the internal dataframe name with this string (e.g., |
return.as |
One of |
Depending on return.as: a data frame, a character string, or a list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.