| rp_select | R Documentation |
Selects specific columns from a data frame. It captures the bare column names and translates the operation into a pandas selection command.
rp_select(.data, ..., table_name = NULL, return.as = "result")
.data |
An R data.frame or tibble. |
... |
The bare column names to select (e.g., |
table_name |
An optional character string. If provided, the generated Python code will replace the internal dataframe name with this string (e.g., |
return.as |
What to return: "result", "code", or "all". |
A data.frame containing only the selected columns.
if (reticulate::py_available(initialize = TRUE) &&
reticulate::py_module_available("pandas")) {
rp_select(ggplot2::diamonds, carat, cut, price)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.